@@ -33,7 +33,8 @@ impl Redirect {
     /// This redirect instructs the client to change the method to GET for the subsequent request
     /// to the given `uri`, which is useful after successful form submission, file upload or when
     /// you generally don't want the redirected-to page to observe the original request method and
-    /// body (if non-empty).
+    /// body (if non-empty). If you want to preserve the request method and body,
+    /// [`Redirect::temporary`] should be used instead.
     ///
     /// # Panics
     ///
@@ -71,16 +72,21 @@ impl Redirect {
 
     /// Create a new [`Redirect`] that uses a [`302 Found`][mdn] status code.
     ///
-    /// This is the same as [`Redirect::temporary`], except the status code is older and thus
-    /// supported by some legacy applications that doesn't understand the newer one, but some of
-    /// those applications wrongly apply [`Redirect::to`] (`303 See Other`) semantics for this
-    /// status code. It should be avoided where possible.
+    /// This is the same as [`Redirect::temporary`] ([`307 Temporary Redirect`][mdn307]) except
+    /// this status code is older and thus supported by some legacy clients that don't understand
+    /// the newer one. Many clients wrongly apply [`Redirect::to`] ([`303 See Other`][mdn303])
+    /// semantics for this status code, so it should be avoided where possible.
     ///
     /// # Panics
     ///
     /// If `uri` isn't a valid [`HeaderValue`].
     ///
     /// [mdn]: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/302
+    /// [mdn307]: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/307
+    /// [mdn303]: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/303
+    #[deprecated(
+        note = "This results in different behavior between clients, so Redirect::temporary or Redirect::to should be used instead"
+    )]
     pub fn found(uri: Uri) -> Self {
         Self::with_status_code(StatusCode::FOUND, uri)
     }
